@@ -225,11 +225,8 @@ async def present(
             Defaults to None.
 
                 * rawKey(str, Optional)
-
                 * rsaEncryptedKey(str, Optional)
-
                 * kmsKeyName(str, Optional)
-
                 * kmsKeyServiceAccount(str, Optional)
 
         source_snapshot_encryption_key(Dict[str, str], Optional):
@@ -238,11 +235,8 @@ async def present(
             Defaults to None.
 
                 * rawKey(str, Optional)
-
                 * rsaEncryptedKey(str, Optional)
-
                 * kmsKeyName(str, Optional)
-
                 * kmsKeyServiceAccount(str, Optional)
 
         labels(Dict[str, Dict[str, str]], Optional):
@@ -363,7 +357,7 @@ async def present(
         resource_id = handle_operation_ret["resource_id"]
 
     if resource_id:
-        old_get_ret = await hub.exec.gcp.compute.disks.get(
+        old_get_ret = await hub.exec.gcp_api.client.compute.disks.get(
             ctx, name=name, resource_id=resource_id
         )
 
@@ -441,14 +435,14 @@ async def present(
         if ctx["test"]:
             result["comment"].append(
                 hub.tool.gcp.comment_utils.would_create_comment(
-                    "gcp.compute.disks", name
+                    "gcp.compute.disk", name
                 )
             )
             result["new_state"] = plan_state
             return result
 
         # Create
-        create_ret = await hub.exec.gcp.compute.disks.insert(
+        create_ret = await hub.exec.gcp_api.client.compute.disks.insert(
             ctx, name=name, project=project, zone=zone, body=resource_body
         )
         if not create_ret["result"]:
@@ -456,7 +450,7 @@ async def present(
             result["comment"] += create_ret["comment"]
             return result
         result["comment"].append(
-            hub.tool.gcp.comment_utils.create_comment("gcp.compute.disks", name)
+            hub.tool.gcp.comment_utils.create_comment("gcp.compute.disk", name)
         )
         result["old_state"] = {}
         resource_id = create_ret["ret"].get("resource_id")
@@ -465,7 +459,7 @@ async def present(
 
     if operation:
         operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
-            operation.get("selfLink"), "compute.zoneOperations"
+            operation.get("selfLink"), "compute.zone_operations"
         )
         handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
             ctx, operation_id, "compute.disks"
@@ -482,7 +476,7 @@ async def present(
     # Try getting the resource again
     # TODO: Reconciliation or waiter loop?
     # TODO: Check if this can be removed because insert and update may also return the necessary data on success
-    get_ret = await hub.exec.gcp.compute.disks.get(
+    get_ret = await hub.exec.gcp_api.client.compute.disks.get(
         ctx, name=name, resource_id=resource_id
     )
 
@@ -558,7 +552,7 @@ async def absent(
 
     if not ctx.get("rerun_data"):
         # First iteration; invoke disk's delete()
-        delete_ret = await hub.exec.gcp.compute.disks.delete(
+        delete_ret = await hub.exec.gcp_api.client.compute.disks.delete(
             ctx, resource_id=resource_id
         )
         if delete_ret["ret"]:
@@ -568,7 +562,7 @@ async def absent(
                 result[
                     "rerun_data"
                 ] = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
-                    delete_ret["ret"].get("selfLink"), "compute.zoneOperations"
+                    delete_ret["ret"].get("selfLink"), "compute.zone_operations"
                 )
                 return result
     else:
@@ -611,12 +605,12 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
     """
     result = {}
 
-    describe_ret = await hub.exec.gcp.compute.disks.aggregatedList(
+    describe_ret = await hub.exec.gcp_api.client.compute.disks.aggregatedList(
         ctx, project=ctx.acct.project_id
     )
 
     if not describe_ret["result"]:
-        hub.log.debug(f"Could not describe gcp.compute.disks {describe_ret['comment']}")
+        hub.log.debug(f"Could not describe disks {describe_ret['comment']}")
         return {}
 
     for resource in describe_ret["ret"]["items"]:
