@@ -17,6 +17,10 @@ def would_update_comment(hub, resource_type: str, name: str) -> str:
     return f"Would update {resource_type} '{name}'"
 
 
+def no_resource_delete_comment(hub, resource_type: str) -> str:
+    return f"Delete operation for resource type {resource_type} is not supported."
+
+
 def delete_comment(hub, resource_type: str, name: str) -> str:
     return f"Deleted {resource_type} '{name}'"
 
