@@ -1,4 +1,5 @@
 import copy
+from typing import Any
 from typing import Dict
 from typing import List
 from typing import Set
@@ -41,6 +42,17 @@ def get_update_properties(hub, resource_type: str, convert_to_present=True) -> S
     return raw_props
 
 
+def get_fields_of_enum_type(hub, resource_type: str, convert_to_present=True) -> Set:
+    raw_props = set(
+        hub.tool.gcp.RESOURCE_PROPS[resource_type].get("fields_enum_type", {})
+    )
+    if convert_to_present:
+        return hub.tool.gcp.conversion_utils.convert_raw_properties_to_present(
+            raw_props
+        )
+    return raw_props
+
+
 def get_get_properties(hub, resource_type: str, convert_to_present=True) -> Set:
     raw_props = set(hub.tool.gcp.RESOURCE_PROPS[resource_type].get("get", {}))
     if convert_to_present:
@@ -66,10 +78,16 @@ def get_non_updatable_properties(hub, resource_type: str) -> Set:
 
 
 def get_present_properties(hub, resource_type: str) -> Set:
-    return hub.tool.gcp.resource_prop_utils.get_create_properties(
-        resource_type, False
-    ).union(
-        hub.tool.gcp.resource_prop_utils.get_update_properties(resource_type, False)
+    return (
+        hub.tool.gcp.resource_prop_utils.get_create_properties(resource_type, False)
+        .union(
+            hub.tool.gcp.resource_prop_utils.get_update_properties(resource_type, False)
+        )
+        .union(
+            hub.tool.gcp.resource_prop_utils.get_fields_of_enum_type(
+                resource_type, False
+            )
+        )
     )
 
 
@@ -77,6 +95,44 @@ def get_exclude_paths(hub, resource_type: str) -> Set:
     return set(hub.tool.gcp.RESOURCE_PROPS[resource_type].get("exclude_paths", {}))
 
 
+def get_exclude_properties_from_transformation(
+    hub, resource_type: str, convert_to_present=True
+) -> Set:
+    resource_methods_properties = hub.tool.gcp.RESOURCE_PROPS[resource_type]
+    raw_props = set(
+        resource_methods_properties.get("exclude_properties_from_transformation", {})
+    )
+    if raw_props and convert_to_present:
+        return hub.tool.gcp.conversion_utils.convert_raw_properties_to_present(
+            raw_props
+        )
+    return raw_props
+
+
+def get_exclude_keys_from_transformation(
+    hub, resource_body: Dict[str, Any], resource_type: str = None
+) -> List[str]:
+    # Get the properties whose keys should be excluded from transformation
+    exclude_properties_from_transformation = (
+        hub.tool.gcp.resource_prop_utils.get_exclude_properties_from_transformation(
+            resource_type
+        )
+    )
+
+    # Create a list, which has lists per each property and have the properties' keys as items
+    list_of_properties_key_lists = [
+        list(resource_body[item].keys()) if resource_body.get(item, False) else []
+        for item in exclude_properties_from_transformation
+    ]
+
+    # Map the list_of_properties_key_lists to a list containing only the keys to be excluded
+    exclude_keys_from_transformation = []
+    for _list in list_of_properties_key_lists:
+        exclude_keys_from_transformation += _list
+
+    return exclude_keys_from_transformation
+
+
 def extract_resource_id(hub, input_props: Dict, resource_type: str) -> Dict:
     # TODO: check that GET, UPDATE, DELETE methods all get the same path params
     # resource_id_path = hub.tool.gcp.resource_prop_utils.get_resource_path(resource_type)
@@ -204,3 +260,14 @@ def format_path_params(hub, resource, resource_type):
             resource_copy[path_el] = resource_copy[path_el].split("/")[-1]
 
     return resource_copy
+
+
+# TODO: Remove this logic once we have all the nested properties defined for a method
+def are_properties_allowed_for_update(hub, resource_type, request_body):
+    can_update = True
+    if resource_type == "compute.instances":
+        for disk in request_body.get("disks" or {}):
+            if disk.get("initialize_params"):
+                can_update = False
+
+    return can_update
